package com.dcsoft.system.consume.service.impl;

import java.util.List;
import com.dcsoft.common.core.utils.DateUtils;
import com.dcsoft.system.consume.domain.ConsumeGroupRecord;
import com.dcsoft.system.consume.mapper.ConsumeGroupRecordMapper;
import com.dcsoft.system.consume.service.IConsumeGroupRecordService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 分组餐补Service业务层处理
 *
 * @author nichun
 * @date 2024-04-12
 */
@Service
public class ConsumeGroupRecordServiceImpl implements IConsumeGroupRecordService
{
    @Autowired
    private ConsumeGroupRecordMapper consumeGroupRecordMapper;

    /**
     * 查询分组餐补
     *
     * @param id 分组餐补主键
     * @return 分组餐补
     */
    @Override
    public ConsumeGroupRecord selectConsumeGroupRecordById(Long id)
    {
        return consumeGroupRecordMapper.selectConsumeGroupRecordById(id);
    }

    /**
     * 查询分组餐补列表
     *
     * @param consumeGroupRecord 分组餐补
     * @return 分组餐补
     */
    @Override
    public List<ConsumeGroupRecord> selectConsumeGroupRecordList(ConsumeGroupRecord consumeGroupRecord)
    {
        return consumeGroupRecordMapper.selectConsumeGroupRecordList(consumeGroupRecord);
    }

    /**
     * 新增分组餐补
     *
     * @param consumeGroupRecord 分组餐补
     * @return 结果
     */
    @Override
    public int insertConsumeGroupRecord(ConsumeGroupRecord consumeGroupRecord)
    {
        consumeGroupRecord.setCreateTime(DateUtils.getNowDate());
        return consumeGroupRecordMapper.insertConsumeGroupRecord(consumeGroupRecord);
    }

    /**
     * 修改分组餐补
     *
     * @param consumeGroupRecord 分组餐补
     * @return 结果
     */
    @Override
    public int updateConsumeGroupRecord(ConsumeGroupRecord consumeGroupRecord)
    {
        consumeGroupRecord.setUpdateTime(DateUtils.getNowDate());
        return consumeGroupRecordMapper.updateConsumeGroupRecord(consumeGroupRecord);
    }

    /**
     * 批量删除分组餐补
     *
     * @param ids 需要删除的分组餐补主键
     * @return 结果
     */
    @Override
    public int deleteConsumeGroupRecordByIds(Long[] ids)
    {
        return consumeGroupRecordMapper.deleteConsumeGroupRecordByIds(ids);
    }

    /**
     * 删除分组餐补信息
     *
     * @param id 分组餐补主键
     * @return 结果
     */
    @Override
    public int deleteConsumeGroupRecordById(Long id)
    {
        return consumeGroupRecordMapper.deleteConsumeGroupRecordById(id);
    }
}
